/* eslint-disable no-mixed-spaces-and-tabs */
import axios, {AxiosInstance, AxiosRequestConfig} from 'axios';
import {ElMessage, ElMessageBox} from 'element-plus';
import {Session} from '/@/utils/storage';
import qs from 'qs';
import {getToken} from "/@/utils/auth.js";
import mgmt from "mgmt-component-v3";

// let loading:any
const isDevelop = import.meta.env.MODE === 'development'
axios.defaults.headers['Content-Type'] = 'application/json;charset=utf-8'
axios.defaults.withCredentials = true;
// 配置新建一个 axios 实例
const service: AxiosInstance = axios.create({
  baseURL: isDevelop ? '/' : window._CONFIG.APIHead,
  timeout: 50000,
  headers: {'Content-Type': 'application/json'},
  paramsSerializer: {
    serialize(params) {
      return qs.stringify(params, {allowDots: true});
    },
  },
});

// 添加请求拦截器
service.interceptors.request.use(
  (config: AxiosRequestConfig) => {
    //  开启 loading 效果
    // loading = ElLoading.service({
    // 	fullscreen: true,
    // 	lock: true,
    // 	text: '正在努力加载,请稍等',
    // 	background: 'rgba(0, 0, 0, 0.7)',
    // });

    // 在发送请求之前做些什么 token
    config.headers!['Authorization'] = `Bearer ${getToken()}`;
    return config;
  },
  (error) => {
    // 对请求错误做些什么
    return Promise.reject(error);
  }
);

// 添加响应拦截器
service.interceptors.response.use(
  (response) => {
    // 关闭 loading 效果
    // loading.close();
    // 对响应数据做点什么
    const res = response.data;
    if (res.code && res.code !== 200) {
      // `token` 过期或者账号已在别处登录
      if (res.code === 401) {
        Session.clear(); // 清除浏览器全部临时缓存
        // ElMessageBox.alert('你已被登出，请重新登录', '提示', {}).then(() => {
          mgmt.toLogin()
        // }).catch(() => {
        // });
      } else {
        ElMessage.error({message: res.msg})
        return Promise.reject(new Error(res.msg));
      }
      return response.data;
    } else {
      return response.data;
    }
  },
  (error) => {
    // 关闭 loading 效果
    // loading.close();
    // 对响应错误做点什么
    const status = error.response.status;
    if (status === 401) {
      Session.clear(); // 清除浏览器全部临时缓存
      // ElMessageBox.alert('你已被登出，请重新登录', '提示', {}).then(() => {
        mgmt.toLogin()
      // }).catch(() => {
      // });
    } else {
      ElMessage({type: 'error', message: error.message})
      return Promise.reject(error);
    }
  }
);

// 导出 axios 实例
export default service;
